==> cms-db_v0.9.tar.gz: admin/updateapi.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	include('friendlyerror.firewall.inc.php');
	die();
}

/*
 * Sends a query to the update server and returns the answer
 * Possible queries are:
 *  - version-unstable: returns the current unstable version
 *  - version-stable:   returns the current stable version
 *                      (once there is one)
 *  - download/VERSION: gets the .tar.gz download link of VERSION
 *  - info/LOCALE:      gets the URL to the release notes in the
 *                      selected language
 */
function query_update_server($q) {
	$version = trim(file_get_contents('../data/version.txt'));
	$curl_version = curl_version();
	$useragent = 'cms-db/'.$version.' libcurl/'.$curl_version['version'];

	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, 'http://update.cms-db.de/update/v1/api.php?'.$q);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
	curl_setopt($ch, CURLOPT_USERAGENT, $useragent);
	$answer = curl_exec($ch);
	curl_close($ch);

	return $answer;
}

/*
 * Checks for updates on the update server
 * Returns:
 *  false, if no update was found
 *  a version number, if an update is available
 */
function update_available($policy) {
	$version = trim(file_get_contents('../data/version.txt'));
	$version = substr($version, 1);
	$version = explode('.', $version);
	$x1 = $version[0];
	$x2 = $version[1];
	if (isset($version[2])) {
		$x3 = $version[2];
	} else {
		$x3 = 0;
	}

	$updateversion = query_update_server('version-'.$policy);
	$version = explode('.', $updateversion);

	if (count($version) < 2) {
		// Server did return some strange value
		return false;
	}

	$n1 = $version[0];
	$n2 = $version[1];
	if (isset($version[2])) {
		$n3 = $version[2];
	} else {
		$n3 = 0;
	}

	if (($n1 > $x1)
	or ($n1 == $x1 and $n2 > $x2)
	or ($n1 == $x1 and $n2 == $x2 and $n3 > $x3)) {
		return $updateversion;
	} else {
		return false;
	}
}

?>

==> cms-db_v0.9.3.tar.gz: admin/updateapi.inc.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	include('friendlyerror.firewall.inc.php');
	die();
}

/*
 * Sends a query to the update server and returns the answer
 * Possible queries are:
 *  - version-unstable: returns the current unstable version
 *  - version-stable:   returns the current stable version
 *                      (once there is one)
 *  - download/VERSION: gets the .tar.gz download link of VERSION
 *  - info/LOCALE:      gets the URL to the release notes in the
 *                      selected language
 */
function query_update_server($q) {
	$version = trim(file_get_contents(CDB_PATH_ADMIN.'/update/version.txt'));
	$curl_version = curl_version();
	$useragent = 'cms-db/'.$version.' libcurl/'.$curl_version['version'];

	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, 'http://update.cms-db.de/update/v1/api.php?'.$q);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
	curl_setopt($ch, CURLOPT_USERAGENT, $useragent);
	$answer = curl_exec($ch);
	curl_close($ch);

	return $answer;
}

/*
 * Checks for updates on the update server
 * Returns:
 *  false, if no update was found
 *  a version number, if an update is available
 */
function update_available($policy) {
	$version = trim(file_get_contents(CDB_PATH_ADMIN.'/update/version.txt'));
	$version = substr($version, 1);
	$version = explode('.', $version);
	$x1 = $version[0];
	$x2 = $version[1];
	if (isset($version[2])) {
		$x3 = $version[2];
	} else {
		$x3 = 0;
	}

	$updateversion = query_update_server('version-'.$policy);
	$version = explode('.', $updateversion);

	if (count($version) < 2) {
		// Server did return some strange value
		return false;
	}

	$n1 = $version[0];
	$n2 = $version[1];
	if (isset($version[2])) {
		$n3 = $version[2];
	} else {
		$n3 = 0;
	}

	if (($n1 > $x1)
	or ($n1 == $x1 and $n2 > $x2)
	or ($n1 == $x1 and $n2 == $x2 and $n3 > $x3)) {
		return $updateversion;
	} else {
		return false;
	}
}

?>
